import * as cdk from 'aws-cdk-lib';
import * as kms from 'aws-cdk-lib/aws-kms';
import * as s3 from 'aws-cdk-lib/aws-s3';
import * as pipelines from 'aws-cdk-lib/pipelines';
import { Construct } from 'constructs';
export interface S3RepositoryConstructProps {
    /**
     * The name of the S3 bucket.
     */
    readonly bucketName: string;
    /**
     * The branch of the repository.
     */
    readonly branch?: string;
    /**
     * The prefix of the S3 bucket.
     */
    readonly prefix?: string;
    /**
     * The encryption key for the S3 bucket.
     */
    readonly encryptionKey: kms.IKey;
    /**
     * The removal policy for the S3 bucket.
     */
    readonly removalPolicy?: cdk.RemovalPolicy;
    /**
     * The roles that have access to the S3 bucket.
     */
    readonly roles?: string[];
    /**
     * Whether to auto-delete objects from the S3 bucket.
     * @default true
     */
    readonly autoDeleteObjects?: boolean;
}
export declare class S3RepositoryConstruct extends Construct {
    readonly bucket: s3.Bucket;
    readonly repositoryBranch: string;
    readonly prefix: string;
    readonly encryptionKey: kms.IKey;
    readonly removalPolicy: cdk.RemovalPolicy;
    readonly pipelineInput: pipelines.IFileSetProducer;
    /**
     * The environment variables for the pipeline.
     */
    readonly pipelineEnvVars: {
        [key: string]: string;
    };
    constructor(scope: Construct, id: string, props: S3RepositoryConstructProps);
}
